@@ -47,9 +47,9 @@ class CommentRepository:
         params = {"body": body, **extraParams}
         return entityRepository.editEntity(comment, params)
 
-    def exportComment(self, comment, rootPath, nameInFolderName=True):
+    def exportComment(self, comment, rootPath):
         commentDir = entityRepository.exportEntity(
-            comment, rootPath, nameInFolderName=nameInFolderName)
+            comment, rootPath)
 
         # export comment
         nestedCommentsDir = commentDir.joinpath('comments')
@@ -57,7 +57,7 @@ class CommentRepository:
 
         for nestedComment in nestedComments:
             nestedComment.export(
-                nestedCommentsDir, nameInFolderName=nameInFolderName)
+                nestedCommentsDir)
 
 
 commentRepository = CommentRepository()
