@@ -78,12 +78,12 @@ class ExperimentRepository:
 
         return entityRepository.editEntity(experiment, params)
 
-    def exportExperiment(self, experiment, root_path, nameInFolderName=True):
+    def exportExperiment(self, experiment, root_path):
 
         experiment.update()
 
         expDir = entityRepository.exportEntity(
-            experiment, root_path, nameInFolderName=nameInFolderName)
+            experiment, root_path)
 
         # export entry
         experiment.root_experiment.export(expDir, folderName='entry')
@@ -93,14 +93,14 @@ class ExperimentRepository:
         protocols = experiment.getProtocols(count=100)
 
         for protocol in protocols:
-            protocol.export(protocolsDir, nameInFolderName=nameInFolderName)
+            protocol.export(protocolsDir)
 
         # export notes
         notesDir = expDir.joinpath('notes')
         notes = experiment.getComments(count=1000)
 
         for note in notes:
-            note.export(notesDir, nameInFolderName=nameInFolderName)
+            note.export(notesDir)
 
         # get html
         html = htmlExportService.getHTML(experiment)
