@@ -29,16 +29,5 @@ class OrganizationRepository:
 
         return entityRepository.newEntity(user, Organization, params)
 
-    def inviteUsers(self, organization, emails, workspace_id=None):
-        url = url_join(API_ROOT, 'api/generic',
-                       'share-link-invitation', 'organization')
-        headers = getHeaders(organization.__user__)
-        json = {
-            'emails': emails,
-            'organization_id': organization.id,
-            'organization_group_id': workspace_id
-        }
-        requestService.post(url=url, headers=headers, json=json)
-
 
 organizationRepository = OrganizationRepository()
