@@ -8,31 +8,33 @@ from labstep.generic.entity.model import Entity
 class OrganizationUser(Entity):
     __entityName__ = "user-organization"
 
-    def promote(self):
+    def setAdmin(self):
         """
-        Promtes a user to admin.
+        Gives a user admin permission over the organization.
 
 
         Example
         -------
         ::
 
-            my_organization.edit(body='My new organization.')
+            users = my_organization.getUsers()
+            user[0].setAdmin()
         """
         from labstep.entities.organizationUser.repository import organizationUserRepository
 
         return organizationUserRepository.promoteUser(self)
 
-    def demote(self):
+    def revokeAdmin(self):
         """
-        Demotes a user to normal member.
+        Revokes admin permissions from a user.
 
 
         Example
         -------
         ::
 
-            my_organization.edit(body='My new organization.')
+            users = my_organization.getUsers()
+            user[0].revokeAdmin()
         """
         from labstep.entities.organizationUser.repository import organizationUserRepository
 
@@ -47,7 +49,8 @@ class OrganizationUser(Entity):
         -------
         ::
 
-            my_organization.edit(body='My new organization.')
+            users = my_organization.getUsers()
+            user[0].disable()
         """
         from labstep.entities.organizationUser.repository import organizationUserRepository
 
