@@ -556,6 +556,35 @@ class User(Entity):
             self, count=count, search_query=search_query, extraParams=extraParams
         )
 
+    def getResourceItems(self, count=100, search_query=None, extraParams={}):
+        """
+        Retrieve a list of a user's ResourceItems on Labstep,
+        which can be filtered using the parameters:
+
+        Parameters
+        ----------
+        count (int)
+            The number of ResourceItems to retrieve.
+        search_query (str)
+            Search for ResourceItems with this 'name'.
+
+        Returns
+        -------
+        List[:class:`~labstep.entities.resourceItem.model.ResourceItem`]
+            A list of ResourceItem objects.
+
+        Example
+        -------
+        ::
+
+            entity = user.getResourceItems(search_query='batch #5')
+        """
+        from labstep.entities.resourceItem.repository import resourceItemRepository
+
+        return resourceItemRepository.getResourceItems(
+            self, count=count, search_query=search_query, extraParams=extraParams
+        )
+
     def getOrderRequests(
         self, count=100, search_query=None, status=None, tag_id=None, extraParams={}
     ):
@@ -981,6 +1010,7 @@ class User(Entity):
     def acceptSharelink(self, token):
         """
         Accept a sharelink
+
         Parameters
         ----------
         token (class)
