@@ -12,6 +12,7 @@ from labstep.service.helpers import (
     getHeaders,
 )
 from labstep.service.request import requestService
+from labstep.config.export import entityNameInFolderName
 
 
 class EntityRepository:
@@ -89,12 +90,12 @@ class EntityRepository:
         entity.__init__(json.loads(response.content), entity.__user__)
         return entity
 
-    def exportEntity(self, entity, rootPath, folderName=None, nameInFolderName=True):
+    def exportEntity(self, entity, rootPath, folderName=None):
 
         from labstep.entities.file.model import File
 
         if folderName is None:
-            if nameInFolderName:
+            if entityNameInFolderName:
                 folderName = f'{entity.id} - {entity.name}' if hasattr(
                     entity, 'name') else f'{entity.id}'
             else:
